@@ -1,5 +1,5 @@
 /**
- * 
+ *
  */
 package com.openexchange.admin.contextrestore.storage.mysqlStorage;
 
@@ -33,14 +33,14 @@ import com.openexchange.log.LogFactory;
 
 /**
  * This class contains all the mysql database related code
- * 
+ *
  * @author <a href="mailto:dennis.sieben@open-xchange.com">Dennis Sieben</a>
- * 
+ *
  */
 public final class OXContextRestoreMySQLStorage extends OXContextRestoreSQLStorage {
 
     private final static Log LOG = LogFactory.getLog(OXContextRestoreMySQLStorage.class);
-    
+
     @Override
     public String restorectx(final Context ctx, final PoolIdSchemaAndVersionInfo poolidandschema) throws SQLException, FileNotFoundException, IOException, OXContextRestoreException, StorageException {
         Connection connection = null;
@@ -82,11 +82,10 @@ public final class OXContextRestoreMySQLStorage extends OXContextRestoreSQLStora
                 close(reader);
             }
             connection.commit();
-            connection.setAutoCommit(true);
             connection2.commit();
-            connection2.setAutoCommit(true);
             doRollback = false;
 
+            connection2.setAutoCommit(true);
             prepareStatement3 = connection2.prepareStatement("SELECT `filestore_name`, `uri` FROM `context` INNER JOIN `filestore` ON context.filestore_id = filestore.id WHERE cid=?");
             prepareStatement3.setInt(1, ctx.getId().intValue());
             final ResultSet executeQuery = prepareStatement3.executeQuery();
@@ -104,8 +103,13 @@ public final class OXContextRestoreMySQLStorage extends OXContextRestoreSQLStora
             }
             closeSQLStuff(prepareStatement, prepareStatement2, prepareStatement3);
             if (null != connection) {
+                autocommit(connection);
                 Database.back(poolId, connection);
             }
+            if (null != connection2) {
+                autocommit(connection2);
+                Database.back(poolId, connection2);
+            }
         }
     }
 
@@ -242,6 +246,24 @@ public final class OXContextRestoreMySQLStorage extends OXContextRestoreSQLStora
         closeSQLStuff(stmt);
     }
 
+    /**
+     * Convenience method to set the auto-commit of a connection to <code>true</code>.
+     *
+     * @param con connection that should go into auto-commit mode.
+     */
+    private static void autocommit(final Connection con) {
+        if (null == con) {
+            return;
+        }
+        try {
+            if (!con.isClosed() && !con.getAutoCommit()) {
+                con.setAutoCommit(true);
+            }
+        } catch (final SQLException e) {
+            LOG.error(e.getMessage(), e);
+        }
+    }
+
     /**
      * Safely closes specified {@link Closeable} instance.
      *
